""" 

Context : SRP
Module  : REM
Version : 1.0.2
Author  : Stefano Covino
Date    : 06/02/2012
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (16/12/2011) First version.
        : (12/01/2012) V. 1.1.0b1.
        : (06/02/2012) V. 1.1.0.
"""

__version__ = '1.1.0'

